WorkerService

Struct WorkerService 

pub struct WorkerService<Q, S, E, F>{ /* private fields */ }
Worker service that processes jobs from the queue.

This service polls for pending jobs and processes them using the HarvestPipeline. It supports both full harvest+embed and metadata-only modes, and graceful shutdown via cancellation tokens.

Implementations

Source

impl<Q, S, E, F> WorkerService<Q, S, E, F>

pub fn new( queue: Q, pipeline: HarvestPipeline<S, E, F>, config: WorkerConfig, ) -> Self

Create a new worker service.

pub async fn run<WR, HR>( &self, cancel_token: CancellationToken, worker_reporter: &WR, harvest_reporter: &HR, ) -> Result<(), AppError>

Run the worker until cancelled.

The worker will:

  1. Poll for available jobs
  2. Claim and process jobs
  3. Handle retries on failure
  4. Release jobs on graceful shutdown
pub async fn process_single_job<WR, HR>( &self, job_id: Uuid, cancel_token: CancellationToken, worker_reporter: &WR, harvest_reporter: &HR, ) -> Result<(), AppError>

Process a single job by ID (for one-off execution, e.g., CLI).

This method is useful for processing a specific job without running the full polling loop.