pub enum HarvestEvent<'a> {
Show 14 variants
BatchStarted {
total_portals: usize,
},
PortalStarted {
portal_index: usize,
total_portals: usize,
portal_name: &'a str,
portal_url: &'a str,
},
ExistingDatasetsFound {
count: usize,
},
PortalDatasetsFound {
count: usize,
},
DatasetProcessed {
current: usize,
total: usize,
created: usize,
updated: usize,
unchanged: usize,
failed: usize,
skipped: usize,
},
PortalCompleted {
portal_index: usize,
total_portals: usize,
portal_name: &'a str,
stats: &'a SyncStats,
},
PortalFailed {
portal_index: usize,
total_portals: usize,
portal_name: &'a str,
error: &'a str,
},
BatchCompleted {
summary: &'a BatchHarvestSummary,
},
PortalCancelled {
portal_index: usize,
total_portals: usize,
portal_name: &'a str,
stats: &'a SyncStats,
},
BatchCancelled {
completed_portals: usize,
total_portals: usize,
},
StaleDetected {
count: usize,
},
CircuitBreakerOpen {
service: &'a str,
retry_after: Duration,
},
PreprocessingStarted {
total: usize,
},
PreprocessingCompleted {
changed: usize,
unchanged: usize,
failed: usize,
},
}Expand description
Events emitted during harvesting operations.
These events provide fine-grained progress information that consumers can use for logging, UI updates, or metrics collection.
Variants
BatchStarted
Batch harvest starting.
PortalStarted
Single portal harvest starting.
Fields
ExistingDatasetsFound
Found existing datasets in database for portal.
PortalDatasetsFound
Found datasets on the portal.
DatasetProcessed
Progress update during dataset processing.
Fields
PortalCompleted
Single portal harvest completed successfully.
Fields
PortalFailed
Single portal harvest failed.
Fields
BatchCompleted
Batch harvest completed.
Fields
summary: &'a BatchHarvestSummaryAggregated summary of all portal results.
PortalCancelled
Single portal harvest was cancelled.
Fields
BatchCancelled
Batch harvest was cancelled.
Fields
StaleDetected
Datasets marked as stale after a successful full sync.
CircuitBreakerOpen
Circuit breaker is open, harvest pausing/failing.
PreprocessingStarted
Pre-processing phase (delta detection / hash check) starting.
PreprocessingCompleted
Pre-processing phase completed — summary before finalization steps (stale detection).
Note: in the streaming pipeline, preprocessing and persistence are interleaved, so this fires after both have completed.